@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactviewer.h"
@@ -145,7 +132,7 @@ public:
             addr.setPhoto(KContacts::Picture());
             addr.setLogo(KContacts::Picture());
             const QString data = QString::fromUtf8(converter.createVCard(addr));
-	    if (mQRCode) {
+            if (mQRCode) {
                 mQRCode->setData(data);
                 mBrowser->document()->addResource(QTextDocument::ImageResource,
                                                   QUrl(QStringLiteral("qrcode")),
@@ -225,7 +212,7 @@ public:
         QString addressBookName;
 
         if (!job->error()) {
-            CollectionFetchJob *fetchJob = qobject_cast<CollectionFetchJob *>(job);
+            auto *fetchJob = qobject_cast<CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
                 const Collection collection = fetchJob->collections().at(0);
                 addressBookName = collection.displayName();
@@ -242,7 +229,7 @@ public:
     QMetaObject::Connection mCollectionFetchJobConnection;
     KContacts::Addressee mCurrentContact;
     Item mCurrentItem;
-    ContactViewer *mParent = nullptr;
+    ContactViewer *const mParent;
     TextBrowser *mBrowser = nullptr;
     AbstractContactFormatter *mContactFormatter = nullptr;
     AbstractContactFormatter *mStandardContactFormatter = nullptr;
@@ -255,7 +242,7 @@ ContactViewer::ContactViewer(QWidget *parent)
     : QWidget(parent)
     , d(new Private(this))
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser = new TextBrowser;
