@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactgroupexpandjob.h"
@@ -64,7 +51,7 @@ public:
             } else {
                 item.setId(reference.uid().toLongLong());
             }
-            ItemFetchJob *job = new ItemFetchJob(item, mParent);
+            auto *job = new ItemFetchJob(item, mParent);
             job->fetchScope().fetchFullPayload();
             job->setProperty("preferredEmail", reference.preferredEmail());
 
@@ -89,7 +76,7 @@ public:
             return;
         }
 
-        ContactGroupSearchJob *searchJob = qobject_cast<ContactGroupSearchJob *>(job);
+        auto *searchJob = qobject_cast<ContactGroupSearchJob *>(job);
 
         if (searchJob->contactGroups().isEmpty()) {
             mParent->emitResult();
@@ -157,7 +144,7 @@ void ContactGroupExpandJob::start()
 {
     if (!d->mName.isEmpty() && !d->mName.contains(QLatin1Char('@'))) {
         // we have to search the contact group first
-        ContactGroupSearchJob *searchJob = new ContactGroupSearchJob(this);
+        auto *searchJob = new ContactGroupSearchJob(this);
         searchJob->setQuery(ContactGroupSearchJob::Name, d->mName);
         searchJob->setLimit(1);
         connect(searchJob, &ContactGroupSearchJob::result, this, [this](KJob *job) {
