@@ -1,22 +1,9 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "phonetypedialog.h"
@@ -36,9 +23,9 @@ PhoneTypeDialog::PhoneTypeDialog(KContacts::PhoneNumber::Type type, QWidget *par
 {
     setWindowTitle(i18nc("@title:window", "Edit Phone Number"));
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
-    QGridLayout *buttonLayout = new QGridLayout;
+    auto *buttonLayout = new QGridLayout;
     layout->addLayout(buttonLayout);
 
     // fill widgets
@@ -76,7 +63,7 @@ KContacts::PhoneNumber::Type PhoneTypeDialog::type() const
     KContacts::PhoneNumber::Type type = {};
 
     for (int i = 0; i < mGroup->buttons().count(); ++i) {
-        QCheckBox *box = qobject_cast<QCheckBox *>(mGroup->buttons().at(i));
+        auto *box = qobject_cast<QCheckBox *>(mGroup->buttons().at(i));
         if (box && box->isChecked()) {
             type |= mTypeList[i];
         }
