@@ -1,22 +1,9 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "imagewidget.h"
@@ -47,10 +34,10 @@ class ImageLoader
 public:
     ImageLoader(QWidget *parent = nullptr);
 
-    QImage loadImage(const QUrl &url, bool *ok, bool selectPictureSize = true);
+    Q_REQUIRED_RESULT QImage loadImage(const QUrl &url, bool *ok, bool selectPictureSize = true);
 
 private:
-    QWidget *mParent = nullptr;
+    QWidget *const mParent;
 };
 
 ImageLoader::ImageLoader(QWidget *parent)
@@ -234,7 +221,7 @@ void ImageWidget::mouseMoveEvent(QMouseEvent *event)
     if ((event->buttons() & Qt::LeftButton)
         && (event->pos() - mDragStartPos).manhattanLength() > QApplication::startDragDistance()) {
         if (mHasImage) {
-            QDrag *drag = new QDrag(this);
+            auto *drag = new QDrag(this);
             drag->setMimeData(new QMimeData());
             drag->mimeData()->setImageData(mPicture.data());
             drag->exec(Qt::CopyAction);
